<?php
namespace Javorszky\Toolbox;

define( 'JGTB_ATS_VALID_PRODUCT_TYPES', apply_filters( 'jgtb_ats_valid_product_types', array( 'simple', 'variation', 'product_variation', 'subscription', 'variable-subscription', 'subscription_variation' ) ) );

add_action( 'woocommerce_after_add_to_cart_form', __NAMESPACE__ . '\\add_to_existing_sub_markup', 21 );
add_action( 'wp_loaded', __NAMESPACE__ . '\\add_product_to_subscription' );
add_action( 'wp_loaded', __NAMESPACE__ . '\\add_products_to_subscription' );
add_action( 'wp_enqueue_scripts', __NAMESPACE__ . '\\add_addtocart_js' );
add_action( 'wp_enqueue_scripts', __NAMESPACE__ . '\\myaccount_scripts' );
add_action( 'woocommerce_subscription_after_actions', __NAMESPACE__ . '\\add_products_to_sub_markup', 11, 1 );
add_action( 'wp_ajax_jgtb_ats_product_search', __NAMESPACE__ . '\\ats_product_search' );
add_action( 'wp_ajax_nopriv_jgtb_ats_product_search', __NAMESPACE__ . '\\ats_product_search' );
add_filter( 'woocommerce_product_data_store_cpt_get_products_query', __NAMESPACE__ . '\\ats_support_search_term_query_var', 10, 2 );

function ats_support_search_term_query_var( $query, $query_vars ) {
	if ( empty( $query_vars['search_term'] ) ) {
		return $query;
	}
	
	$search_term = esc_attr( $query_vars['search_term'] );
	
	if ( 2 >= strlen( $search_term ) ) {
		return $query;
	}

	$query['s'] = $search_term;
	
	return $query;
}

function ats_product_search() {
	check_ajax_referer( 'jgtbwpnonce', 'security' );
	
	$request = stripslashes_deep( $_REQUEST );
	
	if ( isset( $request['action'] ) && 'jgtb_ats_product_search' === $request['action'] && isset( $request['value'] ) && isset( $request['sub_id'] ) ) {
		$value           = esc_attr( $request['value'] );
		$subscription_id = absint( $request['sub_id'] );
		$subscription    = wcs_get_subscription( $subscription_id );
		
		if ( $subscription ) {
			$current_sub_products = array();
			foreach ( $subscription->get_items() as $sub_item ) {
				$current_sub_products[] = 0 < $sub_item['variation_id'] ? absint( $sub_item['variation_id'] ) : $sub_item['product_id'];
			}
			
			$args = apply_filters( 'jgtb_ats_search_products_args', array(
				'exclude'      => $current_sub_products,
				'visibility'   => 'catalog',
				'stock_status' => 'instock',
				'status'       => 'publish',
				'type'         => JGTB_ATS_VALID_PRODUCT_TYPES,
				'search_term'  => $value,
				'limit'        => 10,
			), $subscription );
			
			$products = apply_filters( 'jgtb_ats_search_products', wc_get_products( $args ), $args, $subscription );
			
			// prepare options
			$options = array();
			if ( ! empty( $products ) ) {
				foreach ( $products as $product ) {
					$options[] = array(
						'id'   => $product->get_id(),
						'name' => $product->get_name(),
					);
				}
			}
			
			wp_send_json_success( compact( 'options' ) );
			
		} else {
			$message = __( 'Could not find the subscription!', 'jg-toolbox' );
			wp_send_json_error( compact( 'message' ) );
		}
		
	} else {
		$message = __( 'Product search request data is incomplete or invalid!', 'jg-toolbox' );
		wp_send_json_error( compact( 'message' ) );
	}
	
	exit();
}

/**
 * Hooks into a new action hook in subs to deliver the markup from a template file that child themes can overwrite.
 *
 * @param \WC_Subscription   $subscription   subscription we're operating on
 */
function add_products_to_sub_markup( $subscription ) {
	$allow_add_product = get_option( JGTB_OPTION_PREFIX . 'add_to_subscription', 'no' );

	if ( ! wc_string_to_bool( $allow_add_product ) ) {
		return;
	}

	wc_get_template(
		'myaccount/add-product-to-subscription.php',
		array(
			'subscription' => $subscription,
			'embed_form'   => true,
		),
		'',
		JGTB_PATH . 'templates/'
	);
}

/**
 * Add markup for "Add to existing subscription" to the variable subscription single page.
 */
function add_to_existing_sub_markup() {
	global $product;

	if ( ! is_user_logged_in() || ( $product && ! in_array( $product->get_type(), apply_filters( 'jgtb_available_product_types_for_add_to_subscription', array( 'simple', 'variable', 'subscription', 'variable-subscription' ) ), true ) ) ) {
		return;
	}

	$subscriptions = wcs_get_users_subscriptions();

	$subscriptions = array_filter( $subscriptions, __NAMESPACE__ . '\\remove_subs_with_no_next_payment' );

	$subscriptions = apply_filters( 'jgtb_available_subscriptions_for_product', $subscriptions, $product );

	if ( empty( $subscriptions ) ) {
		return;
	}

	$do_not_show_for_product = $product->get_meta( '_toolbox_hide_add_to_existing', true );
	if ( 'yes' === $do_not_show_for_product ) {
		return;
	}

	wp_register_style( 'add-to-existing', JGTB_URL . 'assets/css/add-to-existing.css', array(), JGTB_VERSION );
	wp_enqueue_style( 'add-to-existing' );

	wc_get_template(
		'single-product/add-to-existing-subscription.php',
		array(
			'product'       => $product,
			'subscriptions' => $subscriptions,
		),
		'',
		JGTB_PATH . 'templates/'
	);
}

/**
 * @param \WC_Subscription $subscription
 * @return mixed
 */
function remove_subs_with_no_next_payment( $subscription ) {
	return $subscription->get_time( 'next_payment' );
}

function add_addtocart_js() {
	global $product, $post;

	if ( ! is_product() ) {
		return;
	}

	$product = wc_get_product( $post->ID );

	$type = $product->get_type();

	if ( 'simple' === $type || 'subscription' === $type ) {
		wp_register_script( 'jgtbatss', JGTB_URL . 'assets/js/jgtbatss.js', array( 'jquery', 'jquery-ui-datepicker', 'wc-add-to-cart' ), JGTB_VERSION, true );
		wp_enqueue_script( 'jgtbatss' );
	} elseif ( 'variable' === $type || 'variable-subscription' === $type ) {
		wp_register_script( 'jgtbatsv', JGTB_URL . 'assets/js/jgtbatsv.js', array( 'jquery', 'jquery-ui-datepicker', 'wc-add-to-cart-variation' ), JGTB_VERSION, true );
		wp_enqueue_script( 'jgtbatsv' );
	}
}

function myaccount_scripts() {
	$allow_add_product = get_option( JGTB_OPTION_PREFIX . 'add_to_subscription', 'no' );
	
	if ( ! is_account_page() && ! is_user_logged_in() && ! wc_string_to_bool( $allow_add_product ) ) {
		return;
	}
	
	wp_register_style( 'selectize-default', JGTB_URL . 'assets/css/selectize.default.css', array(), JGTB_VERSION );
	wp_enqueue_style( 'selectize-default' );

	wp_register_script( 'selectize', JGTB_URL . 'assets/js/selectize.min.js', array( 'jquery' ), JGTB_VERSION, true );
	wp_enqueue_script( 'selectize' );
	
	wp_register_script( 'ats', JGTB_URL . 'assets/js/ats.js', array( 'jquery', 'selectize' ), JGTB_VERSION, true );
	
	wp_localize_script(
		'ats',
		'jgtb_ats',
		array(
			'ajaxurl'                   => admin_url( 'admin-ajax.php' ), // URL to WordPress ajax handling page
			'nonce'                     => wp_create_nonce( 'jgtbwpnonce' ),  
			'selectize_typing_duration' => apply_filters( 'jgtb_ats_selectize_typing_duration', 250 ),
			'selectize_placeholder'     => apply_filters( 'jgtb_ats_selectize_placeholder', __( 'Please enter 2 or more characters', 'jg-toolbox' ) ),
		)
	);
	
	wp_enqueue_script( 'ats' );
}

/**
 * Custom add to cart handler. Instead of adding items to the cart, it will add items to existing subscriptions if
 * a checkbox is checked and a subscription is selected. The code is based on WC_AJAX::add_order_item, which is what
 * happens when you add a new item from the edit subscription page.
 *
 */
function add_product_to_subscription() {
	if ( isset( $_REQUEST['jgtb_add_product_to_existing_subscription'] )
		&& isset( $_REQUEST[ 'jgtbwpnonce_' . $_REQUEST['jgtb_add_product_to_existing_subscription'] ] )
		&& isset( $_REQUEST['add-to-subscription'] )
		&& isset( $_REQUEST['ats_product_id'] )
		&& isset( $_REQUEST['ats_variation_id'] )
		&& isset( $_REQUEST['ats_quantity'] )
		&& isset( $_REQUEST['ats_variation_attributes'] )
	) {
		$user_id       = get_current_user_id();
		$subscription  = wcs_get_subscription( esc_attr( $_REQUEST['jgtb_add_product_to_existing_subscription'] ) );
		$nonce         = esc_attr( $_REQUEST[ 'jgtbwpnonce_' . $_REQUEST['jgtb_add_product_to_existing_subscription'] ] );
		
		if ( Utilities\Validate\validate_subscription_ownership( $user_id, $subscription ) && Utilities\Validate\validate_add_to_subscription_request( $subscription, $nonce ) ) {
			$attributes  = $_REQUEST['ats_variation_attributes'] ? json_decode( stripcslashes( $_REQUEST['ats_variation_attributes'] ), true ) : array();
			$quantity    = $_REQUEST['ats_quantity'] ? absint( $_REQUEST['ats_quantity'] ) : 1;
			$product_id  = ( 0 !== absint( $_REQUEST['ats_variation_id'] ) ) ? absint( $_REQUEST['ats_variation_id'] ) : absint( $_REQUEST['ats_product_id'] );
			
			jgtb_add_product_to_sub( $subscription, $product_id, $quantity, $attributes );
		}

		do_action( 'jgtb_adding_item_to_subscription_failed', $subscription );
	}
}

function add_products_to_subscription() {
	if ( isset( $_REQUEST['jgtb_add_products_to_existing_subscription'] ) && isset( $_REQUEST['ats_id'] ) ) {
		$request         = stripslashes_deep( $_REQUEST );
		$subscription_id = $request['ats_id'] ? absint( $_REQUEST['ats_id'] ) : 0;
		
		if ( 0 === $subscription_id ) {
			return;
		}
		
		$product_ids = isset( $request['ats_products'] ) && is_array( $request['ats_products'] ) ? array_map( 'absint', $request['ats_products'] ) : array();
		
		if ( empty( $product_ids ) ) {
			return;
		}
		
		$subscription = wcs_get_subscription( $subscription_id );
		$nonce_key    = "jgtbwpnonce_{$subscription_id}";
		$nonce        = isset( $request[ $nonce_key ] ) ? esc_attr( $request[ $nonce_key ] ) : false;
		$user_id      = get_current_user_id();
		
		if ( $subscription && $nonce && Utilities\Validate\validate_add_to_subscription_request( $subscription, $nonce ) && Utilities\Validate\validate_subscription_ownership( $user_id, $subscription ) ) {
			foreach ( $product_ids as $product_id ) {
				jgtb_add_product_to_sub( $subscription, $product_id );
			}
		}
	}
}

function jgtb_add_product_to_sub( $subscription, $product_id, $quantity = 1, $attributes = array() ) {
	if ( empty( $product_id ) || ! is_numeric( $product_id ) ) {
		return;
	}

	$product = wc_get_product( absint( $product_id ) );

	if ( ! $product || ! in_array( $product->get_type(), JGTB_ATS_VALID_PRODUCT_TYPES ) ) {
		return;
	}

	if ( 'variation' === $product->get_type() || 'subscription_variation' === $product->get_type() ) {
		$saved_attributes = $product->get_variation_attributes();
		$attributes       = array_intersect_key( $attributes, $saved_attributes );
	}

	$product_data = apply_filters( 'jgtb_add_to_subscription_product_data', array( 'variation' => $attributes ), $product, $subscription, $quantity );
	$subscription->add_product( $product, $quantity, $product_data );

	$subscription->calculate_totals();
	$subscription->add_order_note( 'Customer added a new line item to the subscription: ' . PHP_EOL . $product->get_name() . ' x ' . $quantity . ' (id: ' . $product_id . ')' );
	$subscription->save();

	// translators: placeholder is ID of subscription.
	wc_add_notice( sprintf( _x( 'The item has been added to subscription #%s', 'Notice after product added to subscription.', 'jg-toolbox' ), '<a href="' . esc_url( $subscription->get_view_order_url() ) . '">' . $subscription->get_id() . '</a>' ) );

	do_action( 'jgtb_added_item_to_subscription', $subscription, $product, $quantity );
}
